@@ -42,7 +42,6 @@ these objects be simple dictionaries.
 
 import datetime as dt
 import functools
-import six
 import tempfile
 import time
 
@@ -101,9 +100,8 @@ def engine_reset():
 def serialize(data):
     if data is None:
         return None
-    if isinstance(data, (six.integer_types,
-                         six.string_types,
-                         six.text_type,
+    if isinstance(data, (int,
+                         str,
                          dt.date,
                          dt.time,
                          float,
@@ -231,9 +229,9 @@ def task_create(session, values):
 
     if tags:
         session.bulk_save_objects(
-            models.Tag(uuid=task["uuid"], tag=t,
-                       type=consts.TagType.TASK)
-            for t in set(tags))
+            [models.Tag(uuid=task["uuid"], tag=t,
+                        type=consts.TagType.TASK)
+             for t in set(tags)])
     task["tags"] = tags
     return task
 
@@ -264,8 +262,8 @@ def task_update(session, uuid, values):
 
         if new_tags:
             session.bulk_save_objects(
-                models.Tag(uuid=uuid, tag=t, type=consts.TagType.TASK)
-                for t in set(new_tags))
+                [models.Tag(uuid=uuid, tag=t, type=consts.TagType.TASK)
+                 for t in set(new_tags)])
         task["tags"] = tags
     else:
         task["tags"] = []
@@ -287,7 +285,7 @@ def task_update_status(session, uuid, status, allowed_statuses):
 
 
 @with_session
-def task_list(session, status=None, env=None, tags=None):
+def task_list(session, status=None, env=None, tags=None, uuids_only=False):
     tasks = []
     query = session.query(models.Task)
 
@@ -305,9 +303,13 @@ def task_list(session, status=None, env=None, tags=None):
             return []
         query = query.filter(models.Task.uuid.in_(uuids))
 
+    if uuids_only:
+        query = query.options(sa.orm.load_only("uuid"))
+
     for task in query.all():
         task = task.as_dict()
-        task["tags"] = sorted(tags_get(task["uuid"], consts.TagType.TASK))
+        if not uuids_only:
+            task["tags"] = sorted(tags_get(task["uuid"], consts.TagType.TASK))
         tasks.append(task)
 
     return tasks
@@ -714,9 +716,9 @@ def verification_create(session, verifier_id, env, tags=None, run_args=None):
 
     if tags:
         session.bulk_save_objects(
-            models.Tag(uuid=verification.uuid, tag=t,
-                       type=consts.TagType.VERIFICATION)
-            for t in set(tags)
+            [models.Tag(uuid=verification.uuid, tag=t,
+                        type=consts.TagType.VERIFICATION)
+             for t in set(tags)]
         )
     return verification
 
