@@ -18,8 +18,8 @@ import sys
 
 PARAM_OR_RETURNS_REGEX = re.compile(":(?:param|returns)")
 RETURNS_REGEX = re.compile(":returns: (?P<doc>.*)", re.S)
-PARAM_REGEX = re.compile(":param (?P<name>[\*\w]+): (?P<doc>.*?)"
-                         "(?:(?=:param)|(?=:return)|(?=:raises)|\Z)", re.S)
+PARAM_REGEX = re.compile(r":param (?P<name>[\*\w]+): (?P<doc>.*?)"
+                         r"(?:(?=:param)|(?=:return)|(?=:raises)|\Z)", re.S)
 
 
 def trim(docstring):
@@ -57,7 +57,7 @@ def trim(docstring):
 
 
 def reindent(string):
-    return "\n".join(l.strip() for l in string.strip().split("\n"))
+    return "\n".join(line.strip() for line in string.strip().split("\n"))
 
 
 def parse_docstring(docstring):
