@@ -15,13 +15,12 @@
 
 import collections
 import multiprocessing
+from unittest import mock
 
-import jsonschema
-import mock
+import ddt
 
-from rally.plugins.common.runners import serial
+from rally.plugins.task.runners import serial
 from rally.task import runner
-from rally.task import scenario
 from tests.unit import fakes
 from tests.unit import test
 
@@ -39,32 +38,27 @@ class ScenarioRunnerHelpersTestCase(test.TestCase):
             "duration": 100,
             "idle_duration": 0,
             "output": {"additive": [], "complete": []},
-            "atomic_actions": {},
+            "atomic_actions": [],
             "error": mock_format_exc.return_value
         }
 
-        self.assertEqual(runner.format_result_on_timeout(mock_exc, 100),
-                         expected)
+        self.assertEqual(expected,
+                         runner.format_result_on_timeout(mock_exc, 100))
         mock_format_exc.assert_called_once_with(mock_exc)
 
-    @mock.patch(BASE + "context.ContextManager")
-    def test_get_scenario_context(self, mock_context_manager):
-        mock_context_obj = mock.MagicMock()
-        mock_map_for_scenario = (
-            mock_context_manager.return_value.map_for_scenario)
-
-        self.assertEqual(mock_map_for_scenario.return_value,
-                         runner._get_scenario_context(mock_context_obj))
-
-        mock_context_manager.assert_called_once_with(mock_context_obj)
-        mock_map_for_scenario.assert_called_once_with()
+    def test_get_scenario_context(self):
+        context_obj = {"foo": "bar"}
+        result = runner._get_scenario_context(13, context_obj)
+        self.assertEqual({"foo": "bar", "iteration": 14}, result)
 
     def test_run_scenario_once_internal_logic(self):
         context = runner._get_scenario_context(
-            fakes.FakeContext({}).context)
+            12, fakes.FakeContext({}).context)
         scenario_cls = mock.MagicMock()
-        args = (2, scenario_cls, "test", context, {})
-        runner._run_scenario_once(args)
+        event_queue = mock.MagicMock()
+
+        runner._run_scenario_once(
+            scenario_cls, "test", context, {}, event_queue)
 
         expected_calls = [
             mock.call(context),
@@ -75,10 +69,14 @@ class ScenarioRunnerHelpersTestCase(test.TestCase):
         ]
         scenario_cls.assert_has_calls(expected_calls, any_order=True)
 
+        event_queue.put.assert_called_once_with(
+            {"type": "iteration", "value": 13})
+
     @mock.patch(BASE + "rutils.Timer", side_effect=fakes.FakeTimer)
     def test_run_scenario_once_without_scenario_output(self, mock_timer):
-        args = (1, fakes.FakeScenario, "do_it", mock.MagicMock(), {})
-        result = runner._run_scenario_once(args)
+        result = runner._run_scenario_once(
+            fakes.FakeScenario, "do_it", mock.MagicMock(), {},
+            mock.MagicMock())
 
         expected_result = {
             "duration": fakes.FakeTimer().duration(),
@@ -86,14 +84,15 @@ class ScenarioRunnerHelpersTestCase(test.TestCase):
             "idle_duration": 0,
             "error": [],
             "output": {"additive": [], "complete": []},
-            "atomic_actions": {}
+            "atomic_actions": []
         }
         self.assertEqual(expected_result, result)
 
     @mock.patch(BASE + "rutils.Timer", side_effect=fakes.FakeTimer)
     def test_run_scenario_once_with_added_scenario_output(self, mock_timer):
-        args = (1, fakes.FakeScenario, "with_add_output", mock.MagicMock(), {})
-        result = runner._run_scenario_once(args)
+        result = runner._run_scenario_once(
+            fakes.FakeScenario, "with_add_output", mock.MagicMock(), {},
+            mock.MagicMock())
 
         expected_result = {
             "duration": fakes.FakeTimer().duration(),
@@ -108,121 +107,53 @@ class ScenarioRunnerHelpersTestCase(test.TestCase):
                                      "description": "Complete description",
                                      "title": "Complete",
                                      "chart_plugin": "BarPlugin"}]},
-            "atomic_actions": {}
-        }
-        self.assertEqual(expected_result, result)
-
-    @mock.patch(BASE + "rutils.Timer", side_effect=fakes.FakeTimer)
-    def test_run_scenario_once_with_returned_scenario_output(self, mock_timer):
-        args = (1, fakes.FakeScenario, "with_output", mock.MagicMock(), {})
-        result = runner._run_scenario_once(args)
-
-        expected_result = {
-            "duration": fakes.FakeTimer().duration(),
-            "timestamp": fakes.FakeTimer().timestamp(),
-            "idle_duration": 0,
-            "error": [],
-            "output": {"additive": [{"chart_plugin": "StackedArea",
-                                     "description": "",
-                                     "data": [["a", 1]],
-                                     "title": "Scenario output"}],
-                       "complete": []},
-            "atomic_actions": {}
+            "atomic_actions": []
         }
         self.assertEqual(expected_result, result)
 
     @mock.patch(BASE + "rutils.Timer", side_effect=fakes.FakeTimer)
     def test_run_scenario_once_exception(self, mock_timer):
-        args = (1, fakes.FakeScenario, "something_went_wrong",
-                mock.MagicMock(), {})
-        result = runner._run_scenario_once(args)
+        result = runner._run_scenario_once(
+            fakes.FakeScenario, "something_went_wrong", mock.MagicMock(), {},
+            mock.MagicMock())
         expected_error = result.pop("error")
         expected_result = {
             "duration": fakes.FakeTimer().duration(),
             "timestamp": fakes.FakeTimer().timestamp(),
             "idle_duration": 0,
             "output": {"additive": [], "complete": []},
-            "atomic_actions": {}
+            "atomic_actions": []
         }
         self.assertEqual(expected_result, result)
         self.assertEqual(expected_error[:2],
                          ["Exception", "Something went wrong"])
 
 
-class ScenarioRunnerResultTestCase(test.TestCase):
-
-    def test_validate(self):
-        config = [
-            {
-                "duration": 1.0,
-                "idle_duration": 1.0,
-                "output": {"additive": [], "complete": []},
-                "atomic_actions": {"test1": 1.0},
-                "error": []
-            },
-            {
-                "duration": 2.0,
-                "idle_duration": 2.0,
-                "output": {"additive": [{"chart_plugin": "StackedArea",
-                                         "data": [["a", 1]],
-                                         "title": "Scenario output",
-                                         "description": ""}],
-                           "complete": []},
-                "atomic_actions": {"test2": 2.0},
-                "error": ["a", "b", "c"]
-            }
-        ]
-
-        self.assertEqual(config[0], runner.ScenarioRunnerResult(config[0]))
-        self.assertEqual(config[1], runner.ScenarioRunnerResult(config[1]))
-
-    def test_validate_failed(self):
-        config = {"a": 10}
-        self.assertRaises(jsonschema.ValidationError,
-                          runner.ScenarioRunnerResult, config)
-
-
+@ddt.ddt
 class ScenarioRunnerTestCase(test.TestCase):
 
     @mock.patch(BASE + "rutils.Timer.duration", return_value=10)
     def test_run(self, mock_timer_duration):
+        scenario_class = fakes.FakeClassBasedScenario
         runner_obj = serial.SerialScenarioRunner(
             mock.MagicMock(),
             mock.MagicMock())
+        runner_obj._run_scenario = mock.Mock()
+        context_obj = {"task": runner_obj.task,
+                       "scenario_name": "classbased.fooscenario",
+                       "admin": {"credential": "foo_credentials"},
+                       "config": {}}
 
-        runner_obj._run_scenario = mock.MagicMock()
+        result = runner_obj.run("classbased.fooscenario", context_obj,
+                                {"foo": 11, "bar": "spam"})
 
-        scenario_name = "NovaServers.boot_server_from_volume_and_delete"
-        config_kwargs = {"image": {"id": 1}, "flavor": {"id": 1}}
+        self.assertIsNone(result)
+        self.assertEqual(runner_obj.run_duration,
+                         mock_timer_duration.return_value)
+        self.assertEqual([], list(runner_obj.result_queue))
 
-        context_obj = {
-            "task": runner_obj.task,
-            "scenario_name": scenario_name,
-            "admin": {"credential": mock.MagicMock()},
-            "config": {
-                "cleanup": ["nova", "cinder"], "some_ctx": 2, "users": {}
-            }
-        }
-
-        result = runner_obj.run(scenario_name, context_obj, config_kwargs)
-
-        self.assertEqual(result, mock_timer_duration.return_value)
-        self.assertEqual(list(runner_obj.result_queue), [])
-
-        cls_name, method_name = scenario_name.split(".", 1)
-        cls = scenario.Scenario.get(scenario_name)._meta_get("cls_ref")
-
-        expected_config_kwargs = {"image": 1, "flavor": 1}
         runner_obj._run_scenario.assert_called_once_with(
-            cls, method_name, context_obj, expected_config_kwargs)
-
-    def test_runner_send_result_exception(self):
-        runner_obj = serial.SerialScenarioRunner(
-            mock.MagicMock(),
-            mock.MagicMock())
-        self.assertRaises(
-            jsonschema.ValidationError,
-            lambda: runner_obj._send_result(mock.MagicMock()))
+            scenario_class, "run", context_obj, {"foo": 11, "bar": "spam"})
 
     def test_abort(self):
         runner_obj = serial.SerialScenarioRunner(
@@ -257,12 +188,49 @@ class ScenarioRunnerTestCase(test.TestCase):
         process_pool = collections.deque([process] * processes)
         mock_result_queue = mock.MagicMock(
             empty=mock.MagicMock(return_value=True))
+        mock_event_queue = mock.MagicMock(
+            empty=mock.MagicMock(return_value=True))
 
         runner_obj = serial.SerialScenarioRunner(
             mock.MagicMock(),
             mock.MagicMock())
 
-        runner_obj._join_processes(process_pool, mock_result_queue)
+        runner_obj._join_processes(
+            process_pool, mock_result_queue, mock_event_queue)
 
         self.assertEqual(processes, process.join.call_count)
         mock_result_queue.close.assert_called_once_with()
+
+    def _get_runner(self, task="mock_me", config="mock_me", batch_size=0):
+        class ScenarioRunner(runner.ScenarioRunner):
+            def _run_scenario(self, *args, **kwargs):
+                raise NotImplementedError("Do not run me!")
+
+        task = task if task != "mock_me" else mock.Mock()
+        config = config if config != "mock_me" else mock.Mock()
+
+        scenario_runner = ScenarioRunner(task, config, batch_size)
+        scenario_runner._meta_init()
+        scenario_runner._meta_set("name", "FakePlugin_%s" % id(ScenarioRunner))
+        return scenario_runner
+
+    def test__send_result(self):
+        task = fakes.FakeTask(uuid="foo_uuid")
+        task.result_has_valid_schema = mock.MagicMock(return_value=True)
+        runner_ = self._get_runner(task=task)
+        result = {"timestamp": 42}
+        self.assertIsNone(runner_._send_result(result))
+        self.assertEqual([], runner_.result_batch)
+        self.assertEqual(collections.deque([[result]]), runner_.result_queue)
+
+    @mock.patch("rally.task.runner.LOG")
+    def test__send_result_with_invalid_schema(self, mock_log):
+        task = fakes.FakeTask(uuid="foo_uuid")
+        task.result_has_valid_schema = mock.MagicMock(return_value=False)
+        runner_ = self._get_runner(task=task)
+        result = {"timestamp": 42}
+        self.assertIsNone(runner_._send_result(result))
+        runner_.task.result_has_valid_schema.assert_called_once_with(result)
+        self.assertTrue(mock_log.warning.called)
+        self.assertEqual([], runner_.result_batch)
+        self.assertEqual(collections.deque([]), runner_.result_queue)
